These very nice people have helped create python-roku.

* [jcarbaugh](https://github.com/jcarbaugh)
* [bah2830](https://github.com/bah2830) - added support for currently running app
* [ncmiller](https://github.com/ncmiller) - added device info endpoint
* [dbehnke](https://github.com/dbehnke) - initial Python 3 support
* [DavidCDean](https://github.com/DavidCDean) - bug fix
* [alberthdev](https://github.com/alberthdev) - lowercase and symbol support for literals
* [nharada1](https://github.com/nharada1) - active app property
* [segadude](https://github.com/segadude) and [wilsoc5](https://github.com/wilsoc5) - volume key support
* [bschlenk](https://github.com/bschlenk) - Roku TV commands
